# Security Policy

## Supported DIRAC Versions

| Version | Supported          |
| ------- | ------------------ |
| >= 7.1  | :white_check_mark: |
| < 7.1   | :x:                |

## Reporting a Vulnerability

Please report any suspected vulnerabilities by emailing fstagni-at-cern.ch and atsareg-at-in2p3.fr.
We will respond to you within 2 working days.
If for some reason you do not recieve a response, please follow up via email to ensure we received your original message.
